@@ -22,6 +22,7 @@ from .literals import EnhancedMonitoringType
 from .paginator import (
     ListClusterOperationsPaginator,
     ListClustersPaginator,
+    ListClustersV2Paginator,
     ListConfigurationRevisionsPaginator,
     ListConfigurationsPaginator,
     ListKafkaVersionsPaginator,
@@ -37,11 +38,13 @@ from .type_defs import (
     ConfigurationInfoTypeDef,
     ConnectivityInfoTypeDef,
     CreateClusterResponseTypeDef,
+    CreateClusterV2ResponseTypeDef,
     CreateConfigurationResponseTypeDef,
     DeleteClusterResponseTypeDef,
     DeleteConfigurationResponseTypeDef,
     DescribeClusterOperationResponseTypeDef,
     DescribeClusterResponseTypeDef,
+    DescribeClusterV2ResponseTypeDef,
     DescribeConfigurationResponseTypeDef,
     DescribeConfigurationRevisionResponseTypeDef,
     EncryptionInfoTypeDef,
@@ -49,6 +52,7 @@ from .type_defs import (
     GetCompatibleKafkaVersionsResponseTypeDef,
     ListClusterOperationsResponseTypeDef,
     ListClustersResponseTypeDef,
+    ListClustersV2ResponseTypeDef,
     ListConfigurationRevisionsResponseTypeDef,
     ListConfigurationsResponseTypeDef,
     ListKafkaVersionsResponseTypeDef,
@@ -57,7 +61,9 @@ from .type_defs import (
     ListTagsForResourceResponseTypeDef,
     LoggingInfoTypeDef,
     OpenMonitoringInfoTypeDef,
+    ProvisionedRequestTypeDef,
     RebootBrokerResponseTypeDef,
+    ServerlessRequestTypeDef,
     UpdateBrokerCountResponseTypeDef,
     UpdateBrokerStorageResponseTypeDef,
     UpdateBrokerTypeResponseTypeDef,
@@ -100,7 +106,7 @@ class Exceptions:
 
 class KafkaClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html)
     """
 
@@ -118,7 +124,7 @@ class KafkaClient(BaseClient):
         """
         Associates one or more Scram Secrets with an Amazon MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#batch_associate_scram_secret)
         """
 
@@ -128,7 +134,7 @@ class KafkaClient(BaseClient):
         """
         Disassociates one or more Scram Secrets from an Amazon MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#batch_disassociate_scram_secret)
         """
 
@@ -136,7 +142,7 @@ class KafkaClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#can_paginate)
         """
 
@@ -158,10 +164,25 @@ class KafkaClient(BaseClient):
         """
         Creates a new MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.create_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.create_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#create_cluster)
         """
 
+    def create_cluster_v2(
+        self,
+        *,
+        ClusterName: str,
+        Tags: Mapping[str, str] = ...,
+        Provisioned: "ProvisionedRequestTypeDef" = ...,
+        Serverless: "ServerlessRequestTypeDef" = ...
+    ) -> CreateClusterV2ResponseTypeDef:
+        """
+        Creates a new MSK cluster.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.create_cluster_v2)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#create_cluster_v2)
+        """
+
     def create_configuration(
         self,
         *,
@@ -173,7 +194,7 @@ class KafkaClient(BaseClient):
         """
         Creates a new MSK configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.create_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.create_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#create_configuration)
         """
 
@@ -184,7 +205,7 @@ class KafkaClient(BaseClient):
         Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.delete_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.delete_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#delete_cluster)
         """
 
@@ -192,7 +213,7 @@ class KafkaClient(BaseClient):
         """
         Deletes an MSK Configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.delete_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.delete_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#delete_configuration)
         """
 
@@ -201,7 +222,7 @@ class KafkaClient(BaseClient):
         Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is
         specified in the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.describe_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.describe_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_cluster)
         """
 
@@ -211,15 +232,24 @@ class KafkaClient(BaseClient):
         """
         Returns a description of the cluster operation specified by the ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_cluster_operation)
         """
 
+    def describe_cluster_v2(self, *, ClusterArn: str) -> DescribeClusterV2ResponseTypeDef:
+        """
+        Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is
+        specified in the request.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.describe_cluster_v2)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_cluster_v2)
+        """
+
     def describe_configuration(self, *, Arn: str) -> DescribeConfigurationResponseTypeDef:
         """
         Returns a description of this MSK configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.describe_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.describe_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_configuration)
         """
 
@@ -229,7 +259,7 @@ class KafkaClient(BaseClient):
         """
         Returns a description of this revision of the configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_configuration_revision)
         """
 
@@ -243,7 +273,7 @@ class KafkaClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#generate_presigned_url)
         """
 
@@ -251,7 +281,7 @@ class KafkaClient(BaseClient):
         """
         A list of brokers that a client application can use to bootstrap.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#get_bootstrap_brokers)
         """
 
@@ -261,7 +291,7 @@ class KafkaClient(BaseClient):
         """
         Gets the Apache Kafka versions to which you can update the MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#get_compatible_kafka_versions)
         """
 
@@ -272,7 +302,7 @@ class KafkaClient(BaseClient):
         Returns a list of all the operations that have been performed on the specified
         MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_cluster_operations)
         """
 
@@ -282,17 +312,32 @@ class KafkaClient(BaseClient):
         """
         Returns a list of all the MSK clusters in the current Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.list_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.list_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_clusters)
         """
 
+    def list_clusters_v2(
+        self,
+        *,
+        ClusterNameFilter: str = ...,
+        ClusterTypeFilter: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
+    ) -> ListClustersV2ResponseTypeDef:
+        """
+        Returns a list of all the MSK clusters in the current Region.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.list_clusters_v2)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_clusters_v2)
+        """
+
     def list_configuration_revisions(
         self, *, Arn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListConfigurationRevisionsResponseTypeDef:
         """
         Returns a list of all the MSK configurations in this Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_configuration_revisions)
         """
 
@@ -302,7 +347,7 @@ class KafkaClient(BaseClient):
         """
         Returns a list of all the MSK configurations in this Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.list_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.list_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_configurations)
         """
 
@@ -312,7 +357,7 @@ class KafkaClient(BaseClient):
         """
         Returns a list of Apache Kafka versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_kafka_versions)
         """
 
@@ -322,7 +367,7 @@ class KafkaClient(BaseClient):
         """
         Returns a list of the broker nodes in the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.list_nodes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.list_nodes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_nodes)
         """
 
@@ -332,7 +377,7 @@ class KafkaClient(BaseClient):
         """
         Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_scram_secrets)
         """
 
@@ -340,7 +385,7 @@ class KafkaClient(BaseClient):
         """
         Returns a list of the tags associated with the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_tags_for_resource)
         """
 
@@ -350,7 +395,7 @@ class KafkaClient(BaseClient):
         """
         Reboots brokers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.reboot_broker)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.reboot_broker)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#reboot_broker)
         """
 
@@ -358,7 +403,7 @@ class KafkaClient(BaseClient):
         """
         Adds tags to the specified MSK resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#tag_resource)
         """
 
@@ -366,7 +411,7 @@ class KafkaClient(BaseClient):
         """
         Removes the tags associated with the keys that are provided in the query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#untag_resource)
         """
 
@@ -376,7 +421,7 @@ class KafkaClient(BaseClient):
         """
         Updates the number of broker nodes in the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.update_broker_count)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.update_broker_count)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_count)
         """
 
@@ -390,7 +435,7 @@ class KafkaClient(BaseClient):
         """
         Updates the EBS storage associated with MSK brokers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.update_broker_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.update_broker_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_storage)
         """
 
@@ -400,7 +445,7 @@ class KafkaClient(BaseClient):
         """
         Updates EC2 instance type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.update_broker_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.update_broker_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_type)
         """
 
@@ -411,7 +456,7 @@ class KafkaClient(BaseClient):
         Updates the cluster with the configuration that is specified in the request
         body.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_cluster_configuration)
         """
 
@@ -426,7 +471,7 @@ class KafkaClient(BaseClient):
         """
         Updates the Apache Kafka version for the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_cluster_kafka_version)
         """
 
@@ -440,7 +485,7 @@ class KafkaClient(BaseClient):
         """
         Updates an MSK configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.update_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.update_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_configuration)
         """
 
@@ -450,7 +495,7 @@ class KafkaClient(BaseClient):
         """
         Updates the cluster's connectivity configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.update_connectivity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.update_connectivity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_connectivity)
         """
 
@@ -466,7 +511,7 @@ class KafkaClient(BaseClient):
         """
         Updates the monitoring settings for the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.update_monitoring)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.update_monitoring)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_monitoring)
         """
 
@@ -481,7 +526,7 @@ class KafkaClient(BaseClient):
         """
         Updates the security settings for the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Client.update_security)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Client.update_security)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_security)
         """
 
@@ -490,23 +535,30 @@ class KafkaClient(BaseClient):
         self, operation_name: Literal["list_cluster_operations"]
     ) -> ListClusterOperationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusteroperationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_clusters"]) -> ListClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListClusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListClusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusterspaginator)
         """
 
+    @overload
+    def get_paginator(self, operation_name: Literal["list_clusters_v2"]) -> ListClustersV2Paginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListClustersV2)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclustersv2paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_configuration_revisions"]
     ) -> ListConfigurationRevisionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationrevisionspaginator)
         """
 
@@ -515,7 +567,7 @@ class KafkaClient(BaseClient):
         self, operation_name: Literal["list_configurations"]
     ) -> ListConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationspaginator)
         """
 
@@ -524,14 +576,14 @@ class KafkaClient(BaseClient):
         self, operation_name: Literal["list_kafka_versions"]
     ) -> ListKafkaVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listkafkaversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_nodes"]) -> ListNodesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListNodes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListNodes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listnodespaginator)
         """
 
@@ -540,6 +592,6 @@ class KafkaClient(BaseClient):
         self, operation_name: Literal["list_scram_secrets"]
     ) -> ListScramSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listscramsecretspaginator)
         """
