@@ -12,6 +12,7 @@ Usage::
     from mypy_boto3_kafka.paginator import (
         ListClusterOperationsPaginator,
         ListClustersPaginator,
+        ListClustersV2Paginator,
         ListConfigurationRevisionsPaginator,
         ListConfigurationsPaginator,
         ListKafkaVersionsPaginator,
@@ -23,6 +24,7 @@ Usage::
 
     list_cluster_operations_paginator: ListClusterOperationsPaginator = client.get_paginator("list_cluster_operations")
     list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
+    list_clusters_v2_paginator: ListClustersV2Paginator = client.get_paginator("list_clusters_v2")
     list_configuration_revisions_paginator: ListConfigurationRevisionsPaginator = client.get_paginator("list_configuration_revisions")
     list_configurations_paginator: ListConfigurationsPaginator = client.get_paginator("list_configurations")
     list_kafka_versions_paginator: ListKafkaVersionsPaginator = client.get_paginator("list_kafka_versions")
@@ -38,6 +40,7 @@ from botocore.paginate import Paginator as Boto3Paginator
 from .type_defs import (
     ListClusterOperationsResponseTypeDef,
     ListClustersResponseTypeDef,
+    ListClustersV2ResponseTypeDef,
     ListConfigurationRevisionsResponseTypeDef,
     ListConfigurationsResponseTypeDef,
     ListKafkaVersionsResponseTypeDef,
@@ -49,6 +52,7 @@ from .type_defs import (
 __all__ = (
     "ListClusterOperationsPaginator",
     "ListClustersPaginator",
+    "ListClustersV2Paginator",
     "ListConfigurationRevisionsPaginator",
     "ListConfigurationsPaginator",
     "ListKafkaVersionsPaginator",
@@ -69,7 +73,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListClusterOperationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusteroperationspaginator)
     """
 
@@ -77,14 +81,14 @@ class ListClusterOperationsPaginator(Boto3Paginator):
         self, *, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListClusterOperationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusteroperationspaginator)
         """
 
 
 class ListClustersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListClusters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListClusters)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusterspaginator)
     """
 
@@ -92,14 +96,33 @@ class ListClustersPaginator(Boto3Paginator):
         self, *, ClusterNameFilter: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListClustersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListClusters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListClusters.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusterspaginator)
         """
 
 
+class ListClustersV2Paginator(Boto3Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListClustersV2)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclustersv2paginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        ClusterNameFilter: str = ...,
+        ClusterTypeFilter: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListClustersV2ResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListClustersV2.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclustersv2paginator)
+        """
+
+
 class ListConfigurationRevisionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationrevisionspaginator)
     """
 
@@ -107,14 +130,14 @@ class ListConfigurationRevisionsPaginator(Boto3Paginator):
         self, *, Arn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListConfigurationRevisionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationrevisionspaginator)
         """
 
 
 class ListConfigurationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationspaginator)
     """
 
@@ -122,14 +145,14 @@ class ListConfigurationsPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListConfigurationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListConfigurations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListConfigurations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationspaginator)
         """
 
 
 class ListKafkaVersionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listkafkaversionspaginator)
     """
 
@@ -137,14 +160,14 @@ class ListKafkaVersionsPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListKafkaVersionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listkafkaversionspaginator)
         """
 
 
 class ListNodesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListNodes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListNodes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listnodespaginator)
     """
 
@@ -152,14 +175,14 @@ class ListNodesPaginator(Boto3Paginator):
         self, *, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListNodesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListNodes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListNodes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listnodespaginator)
         """
 
 
 class ListScramSecretsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listscramsecretspaginator)
     """
 
@@ -167,6 +190,6 @@ class ListScramSecretsPaginator(Boto3Paginator):
         self, *, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListScramSecretsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listscramsecretspaginator)
         """
