@@ -20,6 +20,7 @@ from botocore.response import StreamingBody
 from .literals import (
     ClientBrokerType,
     ClusterStateType,
+    ClusterTypeType,
     ConfigurationStateType,
     EnhancedMonitoringType,
     KafkaVersionStatusType,
@@ -51,6 +52,7 @@ __all__ = (
     "ClusterOperationInfoTypeDef",
     "ClusterOperationStepInfoTypeDef",
     "ClusterOperationStepTypeDef",
+    "ClusterTypeDef",
     "CompatibleKafkaVersionTypeDef",
     "ConfigurationInfoTypeDef",
     "ConfigurationRevisionTypeDef",
@@ -58,6 +60,8 @@ __all__ = (
     "ConnectivityInfoTypeDef",
     "CreateClusterRequestRequestTypeDef",
     "CreateClusterResponseTypeDef",
+    "CreateClusterV2RequestRequestTypeDef",
+    "CreateClusterV2ResponseTypeDef",
     "CreateConfigurationRequestRequestTypeDef",
     "CreateConfigurationResponseTypeDef",
     "DeleteClusterRequestRequestTypeDef",
@@ -68,6 +72,8 @@ __all__ = (
     "DescribeClusterOperationResponseTypeDef",
     "DescribeClusterRequestRequestTypeDef",
     "DescribeClusterResponseTypeDef",
+    "DescribeClusterV2RequestRequestTypeDef",
+    "DescribeClusterV2ResponseTypeDef",
     "DescribeConfigurationRequestRequestTypeDef",
     "DescribeConfigurationResponseTypeDef",
     "DescribeConfigurationRevisionRequestRequestTypeDef",
@@ -90,6 +96,8 @@ __all__ = (
     "ListClusterOperationsResponseTypeDef",
     "ListClustersRequestRequestTypeDef",
     "ListClustersResponseTypeDef",
+    "ListClustersV2RequestRequestTypeDef",
+    "ListClustersV2ResponseTypeDef",
     "ListConfigurationRevisionsRequestRequestTypeDef",
     "ListConfigurationRevisionsResponseTypeDef",
     "ListConfigurationsRequestRequestTypeDef",
@@ -112,6 +120,8 @@ __all__ = (
     "PaginatorConfigTypeDef",
     "PrometheusInfoTypeDef",
     "PrometheusTypeDef",
+    "ProvisionedRequestTypeDef",
+    "ProvisionedTypeDef",
     "PublicAccessTypeDef",
     "RebootBrokerRequestRequestTypeDef",
     "RebootBrokerResponseTypeDef",
@@ -119,6 +129,10 @@ __all__ = (
     "S3TypeDef",
     "SaslTypeDef",
     "ScramTypeDef",
+    "ServerlessClientAuthenticationTypeDef",
+    "ServerlessRequestTypeDef",
+    "ServerlessSaslTypeDef",
+    "ServerlessTypeDef",
     "StateInfoTypeDef",
     "StorageInfoTypeDef",
     "TagResourceRequestRequestTypeDef",
@@ -144,6 +158,7 @@ __all__ = (
     "UpdateMonitoringResponseTypeDef",
     "UpdateSecurityRequestRequestTypeDef",
     "UpdateSecurityResponseTypeDef",
+    "VpcConfigTypeDef",
     "ZookeeperNodeInfoTypeDef",
 )
 
@@ -336,6 +351,24 @@ ClusterOperationStepTypeDef = TypedDict(
     total=False,
 )
 
+ClusterTypeDef = TypedDict(
+    "ClusterTypeDef",
+    {
+        "ActiveOperationArn": str,
+        "ClusterType": ClusterTypeType,
+        "ClusterArn": str,
+        "ClusterName": str,
+        "CreationTime": datetime,
+        "CurrentVersion": str,
+        "State": ClusterStateType,
+        "StateInfo": "StateInfoTypeDef",
+        "Tags": Dict[str, str],
+        "Provisioned": "ProvisionedTypeDef",
+        "Serverless": "ServerlessTypeDef",
+    },
+    total=False,
+)
+
 CompatibleKafkaVersionTypeDef = TypedDict(
     "CompatibleKafkaVersionTypeDef",
     {
@@ -436,6 +469,40 @@ CreateClusterResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateClusterV2RequestRequestTypeDef = TypedDict(
+    "_RequiredCreateClusterV2RequestRequestTypeDef",
+    {
+        "ClusterName": str,
+    },
+)
+_OptionalCreateClusterV2RequestRequestTypeDef = TypedDict(
+    "_OptionalCreateClusterV2RequestRequestTypeDef",
+    {
+        "Tags": Mapping[str, str],
+        "Provisioned": "ProvisionedRequestTypeDef",
+        "Serverless": "ServerlessRequestTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateClusterV2RequestRequestTypeDef(
+    _RequiredCreateClusterV2RequestRequestTypeDef, _OptionalCreateClusterV2RequestRequestTypeDef
+):
+    pass
+
+
+CreateClusterV2ResponseTypeDef = TypedDict(
+    "CreateClusterV2ResponseTypeDef",
+    {
+        "ClusterArn": str,
+        "ClusterName": str,
+        "State": ClusterStateType,
+        "ClusterType": ClusterTypeType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredCreateConfigurationRequestRequestTypeDef = TypedDict(
     "_RequiredCreateConfigurationRequestRequestTypeDef",
     {
@@ -548,6 +615,21 @@ DescribeClusterResponseTypeDef = TypedDict(
     },
 )
 
+DescribeClusterV2RequestRequestTypeDef = TypedDict(
+    "DescribeClusterV2RequestRequestTypeDef",
+    {
+        "ClusterArn": str,
+    },
+)
+
+DescribeClusterV2ResponseTypeDef = TypedDict(
+    "DescribeClusterV2ResponseTypeDef",
+    {
+        "ClusterInfo": "ClusterTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeConfigurationRequestRequestTypeDef = TypedDict(
     "DescribeConfigurationRequestRequestTypeDef",
     {
@@ -769,6 +851,26 @@ ListClustersResponseTypeDef = TypedDict(
     },
 )
 
+ListClustersV2RequestRequestTypeDef = TypedDict(
+    "ListClustersV2RequestRequestTypeDef",
+    {
+        "ClusterNameFilter": str,
+        "ClusterTypeFilter": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListClustersV2ResponseTypeDef = TypedDict(
+    "ListClustersV2ResponseTypeDef",
+    {
+        "ClusterInfoList": List["ClusterTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListConfigurationRevisionsRequestRequestTypeDef = TypedDict(
     "_RequiredListConfigurationRevisionsRequestRequestTypeDef",
     {
@@ -1008,6 +1110,61 @@ PrometheusTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredProvisionedRequestTypeDef = TypedDict(
+    "_RequiredProvisionedRequestTypeDef",
+    {
+        "BrokerNodeGroupInfo": "BrokerNodeGroupInfoTypeDef",
+        "KafkaVersion": str,
+        "NumberOfBrokerNodes": int,
+    },
+)
+_OptionalProvisionedRequestTypeDef = TypedDict(
+    "_OptionalProvisionedRequestTypeDef",
+    {
+        "ClientAuthentication": "ClientAuthenticationTypeDef",
+        "ConfigurationInfo": "ConfigurationInfoTypeDef",
+        "EncryptionInfo": "EncryptionInfoTypeDef",
+        "EnhancedMonitoring": EnhancedMonitoringType,
+        "OpenMonitoring": "OpenMonitoringInfoTypeDef",
+        "LoggingInfo": "LoggingInfoTypeDef",
+    },
+    total=False,
+)
+
+
+class ProvisionedRequestTypeDef(
+    _RequiredProvisionedRequestTypeDef, _OptionalProvisionedRequestTypeDef
+):
+    pass
+
+
+_RequiredProvisionedTypeDef = TypedDict(
+    "_RequiredProvisionedTypeDef",
+    {
+        "BrokerNodeGroupInfo": "BrokerNodeGroupInfoTypeDef",
+        "NumberOfBrokerNodes": int,
+    },
+)
+_OptionalProvisionedTypeDef = TypedDict(
+    "_OptionalProvisionedTypeDef",
+    {
+        "CurrentBrokerSoftwareInfo": "BrokerSoftwareInfoTypeDef",
+        "ClientAuthentication": "ClientAuthenticationTypeDef",
+        "EncryptionInfo": "EncryptionInfoTypeDef",
+        "EnhancedMonitoring": EnhancedMonitoringType,
+        "OpenMonitoring": "OpenMonitoringInfoTypeDef",
+        "LoggingInfo": "LoggingInfoTypeDef",
+        "ZookeeperConnectString": str,
+        "ZookeeperConnectStringTls": str,
+    },
+    total=False,
+)
+
+
+class ProvisionedTypeDef(_RequiredProvisionedTypeDef, _OptionalProvisionedTypeDef):
+    pass
+
+
 PublicAccessTypeDef = TypedDict(
     "PublicAccessTypeDef",
     {
@@ -1081,6 +1238,62 @@ ScramTypeDef = TypedDict(
     total=False,
 )
 
+ServerlessClientAuthenticationTypeDef = TypedDict(
+    "ServerlessClientAuthenticationTypeDef",
+    {
+        "Sasl": "ServerlessSaslTypeDef",
+    },
+    total=False,
+)
+
+_RequiredServerlessRequestTypeDef = TypedDict(
+    "_RequiredServerlessRequestTypeDef",
+    {
+        "VpcConfigs": Sequence["VpcConfigTypeDef"],
+    },
+)
+_OptionalServerlessRequestTypeDef = TypedDict(
+    "_OptionalServerlessRequestTypeDef",
+    {
+        "ClientAuthentication": "ServerlessClientAuthenticationTypeDef",
+    },
+    total=False,
+)
+
+
+class ServerlessRequestTypeDef(
+    _RequiredServerlessRequestTypeDef, _OptionalServerlessRequestTypeDef
+):
+    pass
+
+
+ServerlessSaslTypeDef = TypedDict(
+    "ServerlessSaslTypeDef",
+    {
+        "Iam": "IamTypeDef",
+    },
+    total=False,
+)
+
+_RequiredServerlessTypeDef = TypedDict(
+    "_RequiredServerlessTypeDef",
+    {
+        "VpcConfigs": List["VpcConfigTypeDef"],
+    },
+)
+_OptionalServerlessTypeDef = TypedDict(
+    "_OptionalServerlessTypeDef",
+    {
+        "ClientAuthentication": "ServerlessClientAuthenticationTypeDef",
+    },
+    total=False,
+)
+
+
+class ServerlessTypeDef(_RequiredServerlessTypeDef, _OptionalServerlessTypeDef):
+    pass
+
+
 StateInfoTypeDef = TypedDict(
     "StateInfoTypeDef",
     {
@@ -1361,6 +1574,25 @@ UpdateSecurityResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredVpcConfigTypeDef = TypedDict(
+    "_RequiredVpcConfigTypeDef",
+    {
+        "SubnetIds": Sequence[str],
+    },
+)
+_OptionalVpcConfigTypeDef = TypedDict(
+    "_OptionalVpcConfigTypeDef",
+    {
+        "SecurityGroupIds": Sequence[str],
+    },
+    total=False,
+)
+
+
+class VpcConfigTypeDef(_RequiredVpcConfigTypeDef, _OptionalVpcConfigTypeDef):
+    pass
+
+
 ZookeeperNodeInfoTypeDef = TypedDict(
     "ZookeeperNodeInfoTypeDef",
     {
